//
//  StartViewController.swift
//  PointrWidgetSample
//
//  Created by Pointr on 05/11/2021.
//

import UIKit
import PointrKit

class StartViewController: UIViewController {

    @IBOutlet weak var activityIndicator: UIActivityIndicatorView!
    @IBOutlet weak var stateLabel: UILabel!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        stateLabel.text = PTRPointrStateToString(Pointr.shared.state)
    }
    
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        
        // When you want to check any data that is very dynamic and might change very quickly,
        // it's a good practice that you start listening to data changes before you access
        // the current data, so that you don't miss anything.
        // Like in this example where we want to check the current state.
        
        // 1. Add listener first
        Pointr.shared.addListener(self)
        
        // 2. Check data after
        if Pointr.shared.state == .running {
            activityIndicator.stopAnimating()
            presentVenuesList()
        } else {
            PointrHelper.startPointr()
        }
    }
}

extension StartViewController {
    
    func presentVenuesList() {
        if let facilitiesVC = UIStoryboard(name: "Main", bundle: nil).instantiateViewController(withIdentifier: "VenuesViewController") as? VenuesViewController {
            let navController = UINavigationController(rootViewController: facilitiesVC)
            navController.modalPresentationStyle = .fullScreen
            present(navController, animated: true, completion: nil)
        }
    }
}

extension StartViewController: PointrStateChangeListener {
    
    func pointrStateDidChange(to state: PointrState) {
        
        // Pointr SDK callbacks might not be triggered on the main thread
        // so make sure you switch thread if you're doing any UI operations.
        OperationQueue.main.addOperation { [weak self] in
            self?.stateLabel.text = PTRPointrStateToString(state)
            
            switch state {
                
            case .running:
                self?.activityIndicator.stopAnimating()
                self?.presentVenuesList()
                
            case .off, .failedNoInternet, .failedRegistration, .failedValidation:
                self?.activityIndicator.stopAnimating()
            default:
                break
            }
        }
    }
}
